"""This is the "standard" way to include a multiple-line comment in your code."""

# This is a single line comment

def print_list(the_list):
	for item in the_list:
		if isinstance(item, list):
			print("    ")
			print_list(item)
		else:
			print(item)


from distutils.core import setup

setup(
    name = 'nester_volnet',
    version = '1.0.1',
    py_modules = ['nester'],
    author = 'volnet',
    author_email = 'volnet@tom.com',
    url = 'http://volnet.github.io',
    description='A simple printer of nested lists',
)